package test;

/*
 * Copyright (c) 2010 by Intevation GmbH
 *
 * This program is free software under the LGPL (>=v2.1)
 * Read the file LGPL.txt coming with the software for details
 * or visit http://www.gnu.org/licenses/ if it does not exist.
 */

import java.io.IOException;

import org.dive4elements.artifacts.httpclient.exceptions.ConnectionException;
import org.dive4elements.river.client.shared.exceptions.ServerException;
import org.junit.Test;

/**
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */

// REMARK: ignored, because maven will auto-test all tests, but this one needs a running river-artifacts
// For running the JUunit test, the annotation @Ignore has to be disabled
// @Ignore
public class BerechnungsartenTester {

    public static enum CalcMode {
        sinfo_calc_flow_depth, sinfo_calc_flow_depth_development, sinfo_calc_flow_depth_minmax, sinfo_calc_collision, Transportkörperhöhen, sinfo_calc_flood_duration
    };

    public static enum River {
        Beispielfluss, Rhein, Elbe
    };

    public static enum FilenameMapper {

        HELLO_WORLD_FILE("/sinfo/flowdepthminmax/sinfo_flowdepthminmax_export.csv"), //

        // Schäfer-Tests:
        FT_RHEIN_1_FILE("/sinfo/flowdepth/sinfo_ft_01.csv"), //
        FT_RHEIN_3_FILE("/sinfo/flowdepth/sinfo_ft_03.csv"), //

        FTE_ELBE_FILE("/sinfo/flowdepthdevelopment/sinfo_fte_01.csv"), //
        FTE_RHEIN_FILE("/sinfo/flowdepthdevelopment/sinfo_fte_02.csv");

        private final String filename;

        FilenameMapper(final String filename) {
            this.filename = filename;
        }

        public String getFilename() {
            return this.filename;
        }
    }

    private final Boolean overrideFileExport() {
        return null;
    }

    /* FLOWDEPTH MIN MAX */
    @Test
    public void testHelloWorld() throws ServerException, IOException {

        /* Hello World Test */
        RunnerCreatorHelper.createSinfoFlowdepthMinMaxTest(FilenameMapper.HELLO_WORLD_FILE, 10, 100, River.Beispielfluss)
                .runTest(overrideFileExport() != null ? overrideFileExport() : true);
    }

    /* FLOWDEPTH */
    @Test
    public void testRhein1FT() throws ConnectionException, ServerException, IOException {

        RunnerCreatorHelper
                .createSinfoFlowdepthTest(FilenameMapper.FT_RHEIN_1_FILE, 350, 380, River.Rhein, false,
                        new SimpleRecommendation("staticwqkms", "additionals-wstv-0-415", "longitudinal_section"),
                        new SimpleRecommendation("bedheight", "bedheight-soundings-79-2004-DGM-2004_Epoche_NHN", "longitudinal_section"))
                .runTest(overrideFileExport() != null ? overrideFileExport() : true);

    }

    @Test
    public void testRhein3FT() throws ConnectionException, ServerException, IOException {
        RunnerCreatorHelper
                .createSinfoFlowdepthTest(FilenameMapper.FT_RHEIN_3_FILE, 655, 675, River.Rhein, true,
                        new SimpleRecommendation("staticwqkms", "fixations-wstv-0-323", "longitudinal_section"),
                        new SimpleRecommendation("bedheight", "bedheight-soundings-92-2004-NIEDERRHEIN_QP-2004_Epoche_NHN", "longitudinal_section"))
                .runTest(overrideFileExport() != null ? overrideFileExport() : true);
    }

    /* FLOWDEPTH DEVELOPMENT */

    @Test
    public void testElbeFTE() throws ConnectionException, ServerException, IOException {
        RunnerCreatorHelper.createSinfoFlowdepthDevelopmentTest(FilenameMapper.FTE_ELBE_FILE, 210, 230, River.Elbe,
                // current
                new SimpleRecommendation("staticwqkms", "fixations-wstv-0-196", "longitudinal_section", "05.05.2008"), // sicher
                new SimpleRecommendation("bedheight", "bedheight-soundings-66-2008-FP-QP-2008",
                        // "bedheight-single-66-2008-MW-FP-QP-2008",
                        "longitudinal_section"),

                // historical
                new SimpleRecommendation("staticwqkms", "fixations-wstv-0-186", "longitudinal_section", "18.03.1997"), // sicher
                new SimpleRecommendation("bedheight", "bedheight-soundings-70-1995-QP-1995",
                        // "bedheight-single-70-1995-MW-QP-1995",
                        "longitudinal_section"))
                .runTest(overrideFileExport() != null ? overrideFileExport() : true);
    }

    @Test
    public void testRheinFTE() throws ConnectionException, ServerException, IOException {
        RunnerCreatorHelper.createSinfoFlowdepthDevelopmentTest(FilenameMapper.FTE_RHEIN_FILE, 655, 665, River.Rhein,
                // current
                new SimpleRecommendation("staticwqkms", "fixations-wstv-0-372", "longitudinal_section", "23.09.2009-1"), // sicher
                new SimpleRecommendation("bedheight", "bedheight-soundings-80-2008-FP-2008_NHN",
                        // "bedheight-single....",
                        "longitudinal_section"),

                // historical
                new SimpleRecommendation("staticwqkms", "fixations-wstv-0-374", "longitudinal_section", "18.03.1997"), // sicher
                new SimpleRecommendation("bedheight", "bedheight-single-89-1991-MW-NIEDERRHEIN_QP-1991_Epoche_NHN",
                        // "bedheight-soundings-89-1991-NIEDERRHEIN_QP-1991_Epoche_NHN",
                        "longitudinal_section"))
                .runTest(overrideFileExport() != null ? overrideFileExport() : true);
    }

}